#!/bin/csh
#SBATCH --ntasks=1
#SBATCH -N 1 
#SBATCH --job-name=HB-all-intra
#SBATCH -t 06:00:00
#SBATCH --constraint="[ib|qib]"

# Authors: Xiaohong Zhuang, Dr.Jefferey Klauda
#    Date: 4/12/2016

unset noclobber
cd $SLURM_SUBMIT_DIR

module load openmpi/1.6
module load fftw/3.3.3/gnu/4.6.1/openmpi/1.6/shared
setenv LD_LIBRARY_PATH $FFTWLIB
# Xiao: Turn off the mpi warning as infiniband is being used with the OFED verbs driver in DT1.
setenv OMPI_MCA_mpi_warn_on_fork 0  
hostname

# INVOKE CHARMM
# In DT1
  set chm = "/lustre/home/jbklauda/charmm/c39a2wxw/myc39a2/exec/gnu_M/gfortcol.om"
# In DT2
# set chm = "/lustre/xzhuang/software/charmm/c39a2/gnu_M/gfortcol.om"


##############################################################################################################
# UPDATE REGION

# Update the path of your input file
set sdir = "/lustre/xzhuang/simulation/dmpi/charmm-gui"

# Update equilibrated dcd file range
@ f = 36       # first dcd file to read
@ l = 50       # last dcd file to read

# 1. Update lipid type [type] for Glycerol lipids:G ;                Sphingo lipids:S ;  
# 2. Update lipid residue name [rn]  
# 3. Update headgroups [h] for Glycerol lipids:PA/PC/PE/PG/PI/PS;    Sphingo lipids: SM/CER ;
# DON'T includes the sterol,cholestrol lipids here as it has no H acceptor.
# DON'T includes the PC glycerol lipids here as it has no H donor.

# Update the lipid that have both H donor and acceptor for intra-lipid H-bonding
set type = G
set rn   = DMPI
set h    = PI

###################################################################################################################

# Calculate total number of dyns
@ N = ($l - $f + 1)
echo $N > Ndyn.txt

$chm p=${sdir} f=$f l=$l type=$type rn=$rn h=$h < 1_calc_hb_all.inp >& 1_calc_hb_all.out
$chm p=${sdir} f=$f l=$l type=$type rn=$rn h=$h < 1_calc_hb_intra.inp >& 1_calc_hb_intra.out

